<?php

/*

La classe Joueur déclare les attributs correspondant à la table joueur de la base de données.

Elle implémente les différentes requêtes CRUD (create, read, update, delete).

Elle contient une méthode chargePOST() qui récupère les données d'un formulaire.

Les méthodes modifier() et afficher() sont utiles pour les tests, mais pas nécessaires.

joueur -> auteur
prenom a enlever + ajouter les autres parametres 

*/


class Joueur
{
	// attributs en relation avec la base de données
	public $id;
	public $nom;
	public $datedenaissance;
	public $club;
	public $photo;

	// une méthode qui permet de modifier les attributs de l'objet sur lequel elle est appliquée
	function modifier($nom, $datedenaissance, $club, $photo)
	{
		$this->nom = $nom;
		$this->datedenaissance = $datedenaissance;
		$this->club = $club;
		$this->photo = $photo;
	}

	// une méthode pour afficher les attributs de l'objet
	function afficher()
	{
		echo '<p>' . $this->nom . ' ' . $this->datedenaissance . ' (id = ' . $this->id . ')</p>';
	}

	function chargePOST()
	{
		// si une valeur a été reçue dans $_POST['nom'] il faut la copier dans l'attribut nom et la filter
		if (isset($_POST['nom'])) {
			$this->nom = $_POST['nom'];
			$this->nom = strip_tags($this->nom);
			$this->nom = htmlspecialchars($this->nom, ENT_QUOTES, 'UTF-8');
		}
		// si une valeur a été reçue dans $_POST['datedenaissance'] il faut la copier dans l'attribut club et la filter
		if (isset($_POST['datedenaissance'])) {
			$this->datedenaissance = $_POST['datedenaissance'];
			$this->datedenaissance = strip_tags($this->datedenaissance);
			$this->datedenaissance = htmlspecialchars($this->datedenaissance, ENT_QUOTES, 'UTF-8');
		}
		// si une valeur a été reçue dans $_POST['club'] il faut la copier dans l'attribut club et la filter
		if (isset($_POST['club'])) {
			$this->club = $_POST['club'];
			$this->club = strip_tags($this->club);
			$this->club = htmlspecialchars($this->club, ENT_QUOTES, 'UTF-8');
		}
		// si une valeur a été reçue dans $_POST['photo'] il faut la copier dans l'attribut photo et la filter
		if (isset($_POST['photo'])) {
			$this->photo = $_POST['photo'];
			$this->photo = strip_tags($this->photo);
			$this->photo = htmlspecialchars($this->photo, ENT_QUOTES, 'UTF-8');
		}



		// si une valeur a été reçue dans $_POST['id'] il faut la copier dans l'attribut id et la convertir en entier
		if (isset($_POST['id']) && is_numeric($_POST['id'])) {
			$this->id = intval($_POST['id']);
		}
	}

	// une méthode pour récupérer un objet depuis une base de données, grâce à son id
	static function readOne($id)
	{
		// définition de la requête SQL avec un paramètre :valeur
		$sql = 'select * from joueurs where id = :valeur';

		// préparation de la requête
		$pdo = connexion('joueurs');
		$query = $pdo->prepare($sql);

		// on lie le paramètre :valeur à la variable $id reçue
		$query->bindValue(':valeur', $id, PDO::PARAM_INT);

		// exécution de la requête
		$query->execute();

		// récupération de l'unique ligne
		$objet = $query->fetchObject('Joueur');

		// retourne l'objet contenant le résultat
		return $objet;
	}

	// une méthode pour récupérer une table dans un tableau d'objets depuis une base de données
	static function readAll()
	{
		// définition de la requête SQL
		$sql = 'select * from joueurs';

		// préparation de la requête
		$pdo = connexion('joueurs');
		$query = $pdo->prepare($sql);

		// exécution de la requête
		$query->execute();

		// récupération de toutes les lignes sous forme d'objets
		$tableau = $query->fetchAll(PDO::FETCH_CLASS, 'Joueur');

		// retourne le tableau d'objets
		return $tableau;
	}

	// une méthode pour inséré une ligne dans une base de données à partir des attributs de l'objet courant
	function create()
	{
		// construction de la requête :nom, :datedenaissance, :club, :photo, sont les valeurs à insérées
		$sql = 'INSERT INTO joueurs (nom, datedenaissance, club, photo) VALUES (:nom, :datedenaissance, :club, :photo);';

		// préparation de la requête
		$pdo = connexion('joueurs');
		$query = $pdo->prepare($sql);

		// on donne une valeur aux paramètres à partir des attributs de l'objet courant
		$query->bindValue(':nom', $this->nom, PDO::PARAM_STR);
		$query->bindValue(':datedenaissance', $this->datedenaissance, PDO::PARAM_STR);
		$query->bindValue(':club', $this->club, PDO::PARAM_STR);
		$query->bindValue(':photo', $this->photo, PDO::PARAM_STR);

		// exécution de la requête
		$query->execute();

		// on récupère la clé de l'joueur inséré
		$this->id = $pdo->lastInsertId();
	}

	// une méthode pour mettre à jour une ligne dans une base de données à partir des attributs de l'objet courant
	function update()
	{
		// construction de la requête :nom, :datedenaissance, :club, :photo, sont les valeurs à insérées
		$sql = 'UPDATE joueurs SET nom = :nom , datedenaissance = :datedenaissance , club = :club, photo= :photo  WHERE id = :id;';

		// préparation de la requête
		$pdo = connexion('joueurs');
		$query = $pdo->prepare($sql);

		// on donne une valeur aux paramètres à partir des attributs de l'objet courant
		$query->bindValue(':id', $this->id, PDO::PARAM_INT);
		$query->bindValue(':nom', $this->nom, PDO::PARAM_STR);
		$query->bindValue(':club', $this->club, PDO::PARAM_STR);
		$query->bindValue(':datedenaissance', $this->datedenaissance, PDO::PARAM_STR);
		$query->bindValue(':photo', $this->photo, PDO::PARAM_STR);

		// exécution de la requête
		$query->execute();
	}


	// une méthode pour supprimer la ligne dont la clé est fournie en paramètre
	static function delete($id)
	{
		// Attention ligne à supprimer dans vos codes
		// Empêche la suppression des 3 premières lignes pour conserver mes exemples
		

		$sql = 'DELETE FROM joueurs WHERE id = :id;';

		// préparation de la requête
		$pdo = connexion('joueurs');
		$query = $pdo->prepare($sql);

		// on lie le paramètre :id à la variable $id reçue
		$query->bindValue(':id', $id, PDO::PARAM_INT);

		// exécution de la requête
		$query->execute();
	}

	// La création des tables se fait normalement via PhpMyAdmin
	// Cette méthode permet avoir des données neuves pour la correction
	// Initialise une base de données avec quelques données test
	static function init()
	{
		// connexion
		$pdo = connexion('joueurs');

		// suppression des données existantes
		$sql = 'drop table if exists joueurs';
		$query = $pdo->prepare($sql);
		$query->execute();

		// l'attribut auto_increment est différent d'un système à l'autre
		global $config;
		$autoincrement = $config['autoincrement'];

		// création de la table 'users'
		$sql = 'create table joueurs (
				id integer primary key ' . $autoincrement . ',
				nom varchar(50), datedenaissance varchar(50),club varchar(50), photo varchar(256) )';
		$query = $pdo->prepare($sql);
		$query->execute();

		// préparation de la requête d'insertion
		$sql = 'insert into joueurs (nom, datedenaissance, club, photo)
 				values (:nom,:datedenaissance,:club,;photo)';
		$query = $pdo->prepare($sql);

		// données à créer
		$users = [
			['nom' => 'RONALDO', 'datedenaissance' => '1985-02-05', 'club' => 'MANCHESTER UNITED', 'photo' => 'https://www.leparisien.fr/resizer/9A7p2FAOfcFsXYdd_9iUL0pH-VY=/932x582/cloudfront-eu-central-1.images.arcpublishing.com/leparisien/TCIMXPLTUFCTRJZPVGPIE5LQH4.jpg'],
			['nom' => 'BENZEMA', 'datedenaissance' => '1987-12-19', 'club' => 'REAL MADRID', 'photo' => 'https://t2.ldh.be/UxrFXcOhl8Z-JVB1WFLyCtc7J9I=/0x309:2400x1509/940x470/618b7f2a9978e25ff062052d.jpg'],
			['nom' => 'BAME', 'datedenaissance' => '1998-12-20', 'club' => 'PARIS SAINT GERMAIN', 'photo' => 'https://madeinfoot.ouest-france.fr/photos/ligue-1/2020/zoom/l1-20201216224459-3211.jpg']
		];

		// insertion des users
		foreach ($users as $user) {
			$query->bindValue(':nom', $user['nom'], PDO::PARAM_STR);
			$query->bindValue(':datedenaissance', $user['datedenaissance'], PDO::PARAM_STR);
			$query->bindValue(':club', $user['club'], PDO::PARAM_STR);
			$query->bindValue(':photo', $user['photo'], PDO::PARAM_STR);
			$query->execute();
		}
	}
}
