<?php

/*

Il analyse la route, c'est-à-dire les variables (page, action, id) placées sur l'URL.

En fonction des pages et actions, il détermine les requêtes à exécuter et les vues à afficher.

Dans cet exemple, j'ai ajouté une action edit pour afficher le formulaire de modification d'un joueur, 
le formulaire d'ajout d'un joueur est placé dans une page à part. Les deux sont approches sont possibles.

a modiifer pour joueur

*/
include('include/twig.php');
$twig = init_twig();

include('include/class_joueur.php');

include('include/connexion.php');

// Analyse des variables sur l'URL qui définissent la route (page/action/id)
// Les 3 variables $page, $action, $id sont définies

// Récupération de la variable page sur l'URL
if (isset($_GET['page'])) $page = $_GET['page']; else $page = '';

// Récupération de la variable action sur l'URL
if (isset($_GET['action'])) $action = $_GET['action']; else $action = 'read';

// Récupération de l'id s'il existe (par convention la clé 0 correspond à un id inexistant)
if (isset($_GET['id'])) $id = intval($_GET['id']); else $id = 0;

/* Le contrôleur analyse la requête ou la route (ici la page à visualiser)
 * En fonction de la page choisie, il
 * - détermine la vue à utiliser dans la variable $view
 * - fait appel au modèle pour récupérer les données dans la variable $data
 */
switch ($page) {
	case 'joueur' :
		switch ($action) {
			case 'read' :
				// Affiche le joueur dont l'id est sur l'URL
				// Utilise la vue joueur simple avec un message
				$view = 'joueur.twig';
				$data = [
					// La requête readOne récupère les données à afficher
					'joueur' => Joueur::readOne($id),
					'message' => 'Description du joueur'
				];
				break;
			case 'form_create':
				$view = 'form_joueur.twig';
				$data =[];
				break;
			case 'create' :
				// Création d'un joueur (vide)
				$joueur = new Joueur();
				// Récupère les données envoyées par le formulaire (POST)
				$joueur->chargePOST();
				// Requête de création du joueur
				$joueur->create();
				// Utilise la vue joueur simple avec un message
				$view = 'form_joueur.twig';
				$data = [
					'joueur' => $joueur,
					'message' => 'Joueur créé'
				];
				break;
			case 'edit' :
				// Modification d'un joueur : étape 1 => affiche le joueur dans un formulaire
				$view = 'edit_joueur.twig';
				// Le joueur à modifier est récupéré avec la requête readOne
				$data = ['joueur' => Joueur::readOne($id)];
				break;
			case 'update' :
				// Modification d'un joueur : étape 2 => met à jour la base de données
				// Création d'un joueur (vide)
				$joueur = new Joueur();
				// Récupère les données du formulaire = le joueur modifié
				$joueur->chargePOST();
				// Réquête de mise à jour
				$joueur->update();
				// Utilise la vue joueur simple avec un message
				$view = 'joueur.twig';
				$data = [
					'joueur' => $joueur,
					'message' => 'Joueur modifié'
				];
				break;
			case 'delete' :
				// Récupération du joueur pour l'afficher avant la suppression
			//	$joueur = Joueur::readOne($id);
				// Supression du joueur
				Joueur::delete($id);
				// Utilise la vue joueur simple avec un message
				$view = 'joueur.twig';
				$data = [
				//	'joueur' => $joueur,
					'message' => 'Suppression du\'joueurr'
				];
				break;
			default :
				// Page vide ou page d'erreur
				$view = '/base.twig';
				$data = [];
		}
		break;
	case 'form_joueur' :
		// Page affichant un formulaire de saisie d'un nouveau joueur
		// Pourrait aussi être une action de la page joueur
		$view = 'form_joueur.twig';
		$data = [];
		break;
	case 'init' :
		// Page spéciale pour réinitialiser la base de données
		Joueur::init();
	case 'joueurs' :
	default :
		// La page d'accueil affiche tous les joueurs
		$view = 'joueurs.twig';
		$data = ['joueurs' => Joueur::readAll()];
}

// Le contrôleur charge la vue avec les données
echo $twig->render($view, $data);